texlive[45476] trunk: pst2pdf (4oct17)

commits+karl at tug.org commits+karl at tug.org
Thu Oct 5 02:43:04 CEST 2017


Revision: 45476
          http://tug.org/svn/texlive?view=revision&revision=45476
Author:   karl
Date:     2017-10-05 02:43:04 +0200 (Thu, 05 Oct 2017)
Log Message:
-----------
pst2pdf (4oct17)

Modified Paths:
--------------
    trunk/Build/source/texk/texlive/linked_scripts/pst2pdf/pst2pdf.pl
    trunk/Master/texmf-dist/doc/latex/pst2pdf/Changes
    trunk/Master/texmf-dist/doc/latex/pst2pdf/pst2pdf-doc.pdf
    trunk/Master/texmf-dist/doc/latex/pst2pdf/pst2pdf-doc.tex
    trunk/Master/texmf-dist/scripts/pst2pdf/pst2pdf.pl

Modified: trunk/Build/source/texk/texlive/linked_scripts/pst2pdf/pst2pdf.pl
===================================================================
--- trunk/Master/texmf-dist/doc/latex/pst2pdf/Changes	2017-10-05 00:42:49 UTC (rev 45475)
+++ trunk/Master/texmf-dist/doc/latex/pst2pdf/Changes	2017-10-05 00:43:04 UTC (rev 45476)
@@ -1,4 +1,5 @@
 pst2pdf.pl --------
+0.18  2017-10-04  - fix typos in the code comments
 0.17  2017-09-11  - fix escape character in regex
 0.16  2014-09-14  - using gs for split pdf (no more pdftk)
                   - support package pst-exa for examples

Modified: trunk/Master/texmf-dist/doc/latex/pst2pdf/pst2pdf-doc.pdf
===================================================================
(Binary files differ)

Modified: trunk/Master/texmf-dist/doc/latex/pst2pdf/pst2pdf-doc.tex
===================================================================
--- trunk/Master/texmf-dist/doc/latex/pst2pdf/pst2pdf-doc.tex	2017-10-05 00:42:49 UTC (rev 45475)
+++ trunk/Master/texmf-dist/doc/latex/pst2pdf/pst2pdf-doc.tex	2017-10-05 00:43:04 UTC (rev 45476)
@@ -15,7 +15,6 @@
 \usepackage{pst-node}
 \let\pstnodeFV\fileversion
 \let\pstnodeFD\filedate
-%\usepackage{pst-node}
 \usepackage{biblatex}
 
 \addbibresource{\jobname.bib}
@@ -35,8 +34,8 @@
 \begin{document}
 
 \title{\texttt{pst2pdf}}
-\subtitle{Running a PSTricks document with pdflatex;\\  \small v. 0.17}
-\author{Herbert Vo\ss  \\ Pablo Gonz\'{a}lez Luengo}
+\subtitle{Running a PSTricks document with pdflatex;\\  \small v. 0.18}
+\author{Herbert Voß  \\ Pablo Gonz\'{a}lez Luengo}
 \docauthor{}
 \date{\today}
 \maketitle

Modified: trunk/Master/texmf-dist/scripts/pst2pdf/pst2pdf.pl
===================================================================
--- trunk/Build/source/texk/texlive/linked_scripts/pst2pdf/pst2pdf.pl	2017-10-05 00:42:49 UTC (rev 45475)
+++ trunk/Build/source/texk/texlive/linked_scripts/pst2pdf/pst2pdf.pl	2017-10-05 00:43:04 UTC (rev 45476)
@@ -4,9 +4,9 @@
 use strict;			# to be sure, that all is safe ... :-)
 use v5.18;
 # $Id: pst2pdf.pl 119 2014-09-24 12:04:09Z herbert $
-# v. 0.16	 2014-09-14 simplify the use of PSTricks with pdf
-# 2017-09-11	(c) Herbert Voss <hvoss at tug.org> 
-#                   Pablo González Luengo <pablogonz at yahoo.com>
+# v. 0.18	 2017-10-04 simplify the use of PSTricks with pdf
+# (c) Herbert Voss <hvoss at tug.org> 
+#     Pablo González Luengo <pablgonz at yahoo.com>
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@
 
 #---------------- Program identification, options and help -------------
 my $program = 'pst2pdf';
-my $nv='v0.17';
+my $nv='v0.18';
 my $ident = '$Id: pst2pdf.pl 119 2017-09-11 12:04:09Z herbert $';
 my $copyright = <<END_COPYRIGHT ;
 Copyright 2011-2017 (c) Herbert Voss <hvoss\@tug.org> and Pablo González.
@@ -80,7 +80,7 @@
 ${title}Usage: $program <texfile.tex>  [Options]
 pst2pdf run a TeX source, read all PS-related part and convert in images
 	in pdf,eps,jpg or png format (default pdf) and create new file 
-	whitout pst-enviroment and runs (pdf/Xe)latex. 
+	whitout pst-environment and runs (pdf/Xe)latex. 
 	See pst2pdf documentation for more info.
 Options:
   -h,--help          - display this help and exit
@@ -109,7 +109,7 @@
 * $program test.tex -e -p -j -c --imgdir=pics
 * produce test-pdf.tex whitout pstriks related parts and create image
 * dir whit all images (pdf,eps,png,jpg) and source (.tex) for all pst 
 * enviroment in "pics" dir using Ghostscript and cleaning all tmp files. 
 * suport bundling for short options $program test.tex -epjc --imgdir=pics
 END_OF_USAGE
 #
@@ -1037,7 +1037,7 @@
     } # close ppm
 } # cerramos runPSTimg
 
 #--------------------- Replace PST enviroment for images----------------
 sub runpdfTeX() {
 
   my ($name,$pdfname) = @_;
@@ -109,7 +109,7 @@
 * produce test-pdf.tex whitout pstriks related parts and create image
 * dir whit all images (pdf,eps,png,jpg) and source (.tex) for all pst 
-* enviroment in "pics" dir using Ghostscript and cleaning all tmp files. 
+* environment in "pics" dir using Ghostscript and cleaning all tmp files. 
 * suport bundling for short options $program test.tex -epjc --imgdir=pics
 END_OF_USAGE
@@ -1037,7 +1037,7 @@
 } # cerramos runPSTimg
 
-#--------------------- Replace PST enviroment for images----------------
+#--------------------- Replace PST environment for images----------------
 sub runpdfTeX() {
 

Modified: trunk/Master/texmf-dist/doc/latex/pst2pdf/Changes
===================================================================
--- trunk/Master/texmf-dist/scripts/pst2pdf/pst2pdf.pl	2017-10-05 00:42:49 UTC (rev 45475)
+++ trunk/Master/texmf-dist/scripts/pst2pdf/pst2pdf.pl	2017-10-05 00:43:04 UTC (rev 45476)
@@ -4,9 +4,9 @@
 use strict;			# to be sure, that all is safe ... :-)
 use v5.18;
 # $Id: pst2pdf.pl 119 2014-09-24 12:04:09Z herbert $
-# v. 0.16	 2014-09-14 simplify the use of PSTricks with pdf
-# 2017-09-11	(c) Herbert Voss <hvoss at tug.org> 
-#                   Pablo González Luengo <pablogonz at yahoo.com>
+# v. 0.18	 2017-10-04 simplify the use of PSTricks with pdf
+# (c) Herbert Voss <hvoss at tug.org> 
+#     Pablo González Luengo <pablgonz at yahoo.com>
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@
 
 #---------------- Program identification, options and help -------------
 my $program = 'pst2pdf';
-my $nv='v0.17';
+my $nv='v0.18';
 my $ident = '$Id: pst2pdf.pl 119 2017-09-11 12:04:09Z herbert $';
 my $copyright = <<END_COPYRIGHT ;
 Copyright 2011-2017 (c) Herbert Voss <hvoss\@tug.org> and Pablo González.
@@ -80,7 +80,7 @@
 ${title}Usage: $program <texfile.tex>  [Options]
 pst2pdf run a TeX source, read all PS-related part and convert in images
 	in pdf,eps,jpg or png format (default pdf) and create new file 
-	whitout pst-enviroment and runs (pdf/Xe)latex. 
+	whitout pst-environment and runs (pdf/Xe)latex. 
 	See pst2pdf documentation for more info.
 Options:
   -h,--help          - display this help and exit
@@ -109,7 +109,7 @@
 * $program test.tex -e -p -j -c --imgdir=pics
 * produce test-pdf.tex whitout pstriks related parts and create image
 * dir whit all images (pdf,eps,png,jpg) and source (.tex) for all pst 
 * enviroment in "pics" dir using Ghostscript and cleaning all tmp files. 
 * suport bundling for short options $program test.tex -epjc --imgdir=pics
 END_OF_USAGE
 #
@@ -1037,7 +1037,7 @@
     } # close ppm
 } # cerramos runPSTimg
 
 #--------------------- Replace PST enviroment for images----------------
 sub runpdfTeX() {
 
   my ($name,$pdfname) = @_;
@@ -109,7 +109,7 @@
 * produce test-pdf.tex whitout pstriks related parts and create image
 * dir whit all images (pdf,eps,png,jpg) and source (.tex) for all pst 
-* enviroment in "pics" dir using Ghostscript and cleaning all tmp files. 
+* environment in "pics" dir using Ghostscript and cleaning all tmp files. 
 * suport bundling for short options $program test.tex -epjc --imgdir=pics
 END_OF_USAGE
@@ -1037,7 +1037,7 @@
 } # cerramos runPSTimg
 
-#--------------------- Replace PST enviroment for images----------------
+#--------------------- Replace PST environment for images----------------
 sub runpdfTeX() {
 



More information about the tex-live-commits mailing list